==> bdnavs-0.0.1.tar.gz: lib/bdnavs.dart <==
library bdnavs;

import 'package:flutter/material.dart';

import 'BottomNavigationBar/bottom_navigation_bar.dart';


bool index1 = true;
bool index2 = false;
bool index3 = false;
bool index4 = false;
bool index5 = false;


class NavBs4Down extends StatefulWidget {
  NavBs4Down(
      {Key key,
        this.iconColors, this.iconBackColors, this.icons, this.app , this.index ,this.iconDisableColors, this.navBackColors, this.isDown});
  final Color iconColors;
  final Color iconBackColors;
  final List<IconData> icons;
  final List app;
  final int index;
  final Color iconDisableColors;
  final Color navBackColors;
  final bool isDown;
  
  
  @override
  _NavBs4DownPageState createState() => _NavBs4DownPageState();
}

class _NavBs4DownPageState extends State<NavBs4Down> {
  
  @override
  void initState() {
    super.initState();
  }
  void onBottomIconPressed(int index) {
    if (index == 0) {
      setState(() {
        index1= true;
        index2 = false;
        index3 = false;
        index4 = false;
        // ignore: unnecessary_statements
        widget.index==5?index5 = false:index4;
      });
    } else if (index == 1) {
      setState(() {
        index1 = false;
        index2 = true;
        index3 = false;
        index4 = false;
        // ignore: unnecessary_statements
        widget.index==5?index5 = false:index4;
      });
    }  else if (index == 2) {
      setState(() {
        index1 = false;
        index2 = false;
        index3 = true;
        index4 = false;
        // ignore: unnecessary_statements
        widget.index==5?index5 = false:index4;
      });
    } else if (index == 3) {
      setState(() {
        index1 = false;
        index2 = false;
        index3 = false;
        index4 = true;
        // ignore: unnecessary_statements
        widget.index==5?index5 = false:index4;
      });
    } else {
      setState(() {
        index1 = false;
        index2 = false;
        index3 = false;
        index4 = false;
        // ignore: unnecessary_statements
        widget.index==5?index5 = true:index4;
      });
    }
  }
  
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home:Scaffold(
        body:Container(
          height: 100,
          child: AnimatedSwitcher(
            duration: Duration(milliseconds: 300),
            switchInCurve: Curves.easeInToLinear,
            switchOutCurve: Curves.easeOutBack,
            child: index1 ? widget.app[0] :index2?widget.app[1]:index3?widget.app[2]: index4?widget.app[3]:widget.app[4],
            ),
          ),
        bottomNavigationBar: CustomBottomNavigationBar(
            index: widget.index,
            onIconPresedCallback: onBottomIconPressed,
            iconColors: widget.iconColors,
            iconBackColors:widget.iconBackColors,
            iconDisableColors: widget.iconDisableColors,
            navBackColors:widget.navBackColors,
            icons: widget.icons,//only 4 icons
            isDown: widget.isDown
            ),
        ),
      );
  }
}

==> bdnavs-0.0.3.tar.gz: lib/bdnavs.dart <==
library bdnavs;

import 'package:flutter/material.dart';

import 'BottomNavigationBar/bottom_navigation_bar.dart';

bool index1 = true;
bool index2 = false;
bool index3 = false;
bool index4 = false;
bool index5 = false;

class NavBs4Down extends StatefulWidget {
  NavBs4Down(
      {Key key,
      this.iconColors,
      this.iconBackColors,
      this.icons,
      this.app,
      this.index,
      this.iconDisableColors,
      this.navBackColors,
      this.isDown});

  final Color iconColors;
  final Color iconBackColors;
  final List<IconData> icons;
  final List app;
  final int index;
  final Color iconDisableColors;
  final Color navBackColors;
  final bool isDown;

  @override
  _NavBs4DownPageState createState() => _NavBs4DownPageState();
}

class _NavBs4DownPageState extends State<NavBs4Down> {
  @override
  void initState() {
    super.initState();
  }

  void onBottomIconPressed(int index) {
    if (index == 0) {
      setState(() {
        index1 = true;
        index2 = false;
        index3 = false;
        index4 = false;
        // ignore: unnecessary_statements
        widget.index == 5 ? index5 = false : index4;
      });
    } else if (index == 1) {
      setState(() {
        index1 = false;
        index2 = true;
        index3 = false;
        index4 = false;
        // ignore: unnecessary_statements
        widget.index == 5 ? index5 = false : index4;
      });
    } else if (index == 2) {
      setState(() {
        index1 = false;
        index2 = false;
        index3 = true;
        index4 = false;
        // ignore: unnecessary_statements
        widget.index == 5 ? index5 = false : index4;
      });
    } else if (index == 3) {
      setState(() {
        index1 = false;
        index2 = false;
        index3 = false;
        index4 = true;
        // ignore: unnecessary_statements
        widget.index == 5 ? index5 = false : index4;
      });
    } else {
      setState(() {
        index1 = false;
        index2 = false;
        index3 = false;
        index4 = false;
        // ignore: unnecessary_statements
        widget.index == 5 ? index5 = true : index4;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        body: Container(
          height: 100,
          child: AnimatedSwitcher(
            duration: Duration(milliseconds: 300),
            switchInCurve: Curves.easeInToLinear,
            switchOutCurve: Curves.easeOutBack,
            child: index1
                ? widget.app[0]
                : index2
                    ? widget.app[1]
                    : index3
                        ? widget.app[2]
                        : index4 ? widget.app[3] : widget.app[4],
          ),
        ),
        bottomNavigationBar: CustomBottomNavigationBar(
            index: widget.index,
            onIconPresedCallback: onBottomIconPressed,
            iconColors: widget.iconColors,
            iconBackColors: widget.iconBackColors,
            iconDisableColors: widget.iconDisableColors,
            navBackColors: widget.navBackColors,
            icons: widget.icons, //only 4 icons
            isDown: widget.isDown),
      ),
    );
  }
}
